package com.devbeh;


import java.util.List;


public class DbmProperties
{
    /**
     * Максимальное количество кадров в секунду по умолчанию.
     */
    private int maxFps;

    /**
     * Максимальный размер кадра в пикселях, полученный как height * width.
     */
    private int maxFrameSizePixels = 720 * 720; //720 * 1240;

    /**
     * Kafka bootstrap сервер.
     */
    private String bootstrapServer;

    /**
     * Kafka username или null.
     */
    private String username = null;

    /**
     * Kafka password или null.
     */
    private String password = null;

    /**
     * Имя топика запросов на обработку кадров компонентом детектирования.
     */
    private String detectionRequestTopicName = "detection-requests";

    /**
     * Префикс имени топика результатов детектирования.
     */
    private String detectionResponseTopicPrefix = "detection-results-";

    /**
     * Имя топика запросов на обработку кадров компонентом детектирования.
     */
    private String trackingRequestTopicName = "tracking-requests";

    /**
     * Префикс имени топика результатов детектирования. Для получения полного имени топика к префиксу добавляется
     * номер видео.
     */
    private String trackingResponseTopicPrefix = "tracking-results-";

    /**
     * Префикс имени топика, хранящего записи изменения состояния менеджера трекинга. Для получения полного имени
     * топика к префиксу добавляется номер видео.
     */
    private String trackingManagerStateTopicPrefix = "tracking-manager-state-";

    /**
     * Имя топика запросов на обработку кадров компонентом оценки трехмерных поз.
     */
    private String poseRequestTopicName = "pose3d-requests";

    /**
     * Префикс имени топика результатов оценки трехмерных поз.
     */
    private String poseResponseTopicPrefix = "pose3d-results-";

    /**
     * Имя топика запросов на обработку кадров компонентом оценки трехмерных поз.
     */
    private String distanceRequestTopicName = "distance-requests";

    /**
     * Префикс имени топика результатов оценки трехмерных поз.
     */
    private String distanceResponseTopicPrefix = "distance-results-";

    /**
     * Имя топика запросов на обработку кадров компонентом детектирования действий.
     */
    private String actionsRequestTopicName = "actions-requests";

    /**
     * Префикс имени топика результатов детектирования действий.
     */
    private String actionsResponseTopicPrefix = "actions-results-";

    /**
     * Префикс имени топика, содержащего знания, извлеченные из кадров.
     */
    private String kbStateTopicPrefix = "kb-state-";

    /**
     * Префикс имени топика результатов детектирования девиантного поведения людей.
     */
    private String devBehDetectionsTopicPrefix = "dev-beh-detections-";

    /**
     * Путь к директории, в которую будут записаны отрывки видеозаписи с результатами детектирования девиантного
     * поведения.
     */
    private String devBehDetectionsDirPath;

    /**
     * Идентификатор начального кадра, с которого следует обрабатывать детектированные случаи девиантного поведения -
     * создавать результирующие видеозаписи.
     */
    private long devBehDetectionsStartFrameId;

    /**
     * Путь к директории, в которую будут записаны видеозаписи с отображенными результатами машинного восприятия.
     */
    private String perceptionResultDirPath;

    /**
     * Идентификатор начального кадра, с которого необходимо формировать результирующее видео.
     */
    private long perceptionInitialConsumedFrameId;

    /**
     * Переключатель создания видеозаписи с отображенными результатами машинного восприятия.
     */
    private boolean perceptionVisualizationEnabled = false;

    /**
     * Размер интервала, за который в базе знаний хранится история.
     */
    private int kbHistoryIntervalSec;

    /**
     * Максимальное время, которое объект может быть перекрыт, после чего объект будет "забыт".
     * Должно быть не больше значения, заданного в трекере.
     */
    private int maxOccludedDurationSec;

    /**
     * Используется для вычисления точки касания объекта с землей. Считается, что точка касания расположена посередине
     * обрамляющей рамки по оси x и на данный процент выше нижней точки рамки. Процент вычисляется относительно высоты
     * рамки.
     */
    private float boxContactPointLiftPercent = 0.15f;

    /**
     * Период, с которым осуществляется логический вывод по базе знаний для детектирования девиантного поведения людей.
     */
    private int inferencePeriodSec = 10;

    /**
     * Период, в течение которого после детектирования определенного инстанса девиантного поведения, аналогичные
     * инстансы будут проигнорированы (инстансы одного типа девиантного поведения с одними действующими лицами).
     */
    private int devBehIgnorePeriodSec = 60;

    /**
     * Путь к jar файлу компонента kb-worker.
     */
    private String kbWorkerJarPath;

    /**
     * Значение Xms/Xmx параметров запуска компонент kb-worker.
     */
    private String kbWorkerMemory = "512m";

    /**
     * Путь к директории, хранящей библиотечный файл libjpl.so (например, /usr/lib/swi-prolog/lib/x86_64-linux).
     */
    private String libjplJavaLibraryPath;

    /**
     * Путь к файлу (в формате .pl), содержащему общие знания, используемые для всех экземпляров бз.
     */
    private String generalKbRulesFilePath;

    /**
     * Максимальная длительность действия в секундах. При превышении данного значения действие принудительно
     * завершается, но может быть переоткрыто на следующем кадре.
     */
    private int maxActionDurationSec = 15;

    /**
     * Максимальный размер скелета ребенка в миллиметрах.
     */
    private int maxChildSkeletonLengthMm = 3400 / 3;

    /**
     * Максимальное количество кадров, находящееся в очереди на обработку и, следовательно, занимающих место в
     * оперативной памяти.
     */
    private int maxQueuedFrames = 5;

    /**
     * Максимальное количество кадров, находящееся в обработке компонентом анализа (отправленных в Kafka без получения
     * результата).
     */
    private int maxProcessingFrames = 5;

    /**
     * Конфигурация провайдеров видео, считывающих их из файлов.
     */
    private List<FileVideoProviderProperties> fileVideoProviders;


    public int getMaxFps()
    {
        return maxFps;
    }


    public void setMaxFps(int maxFps)
    {
        this.maxFps = maxFps;
    }


    public int getMaxFrameSizePixels()
    {
        return maxFrameSizePixels;
    }


    public void setMaxFrameSizePixels(int maxFrameSizePixels)
    {
        this.maxFrameSizePixels = maxFrameSizePixels;
    }


    public String getBootstrapServer()
    {
        return bootstrapServer;
    }


    public void setBootstrapServer(String bootstrapServer)
    {
        this.bootstrapServer = bootstrapServer;
    }


    public String getUsername()
    {
        return username;
    }


    public void setUsername(String username)
    {
        this.username = username;
    }


    public String getPassword()
    {
        return password;
    }


    public void setPassword(String password)
    {
        this.password = password;
    }


    public String getDetectionRequestTopicName()
    {
        return detectionRequestTopicName;
    }


    public void setDetectionRequestTopicName(String detectionRequestTopicName)
    {
        this.detectionRequestTopicName = detectionRequestTopicName;
    }


    public String getDetectionResponseTopicPrefix()
    {
        return detectionResponseTopicPrefix;
    }


    public void setDetectionResponseTopicPrefix(String detectionResponseTopicPrefix)
    {
        this.detectionResponseTopicPrefix = detectionResponseTopicPrefix;
    }


    public String getTrackingRequestTopicName()
    {
        return trackingRequestTopicName;
    }


    public void setTrackingRequestTopicName(String trackingRequestTopicName)
    {
        this.trackingRequestTopicName = trackingRequestTopicName;
    }


    public String getTrackingResponseTopicPrefix()
    {
        return trackingResponseTopicPrefix;
    }


    public void setTrackingResponseTopicPrefix(String trackingResponseTopicPrefix)
    {
        this.trackingResponseTopicPrefix = trackingResponseTopicPrefix;
    }


    public String getTrackingManagerStateTopicPrefix()
    {
        return trackingManagerStateTopicPrefix;
    }


    public void setTrackingManagerStateTopicPrefix(String trackingManagerStateTopicPrefix)
    {
        this.trackingManagerStateTopicPrefix = trackingManagerStateTopicPrefix;
    }


    public String getPoseRequestTopicName()
    {
        return poseRequestTopicName;
    }


    public void setPoseRequestTopicName(String poseRequestTopicName)
    {
        this.poseRequestTopicName = poseRequestTopicName;
    }


    public String getPoseResponseTopicPrefix()
    {
        return poseResponseTopicPrefix;
    }


    public void setPoseResponseTopicPrefix(String poseResponseTopicPrefix)
    {
        this.poseResponseTopicPrefix = poseResponseTopicPrefix;
    }


    public String getDistanceRequestTopicName()
    {
        return distanceRequestTopicName;
    }


    public void setDistanceRequestTopicName(String distanceRequestTopicName)
    {
        this.distanceRequestTopicName = distanceRequestTopicName;
    }


    public String getDistanceResponseTopicPrefix()
    {
        return distanceResponseTopicPrefix;
    }


    public void setDistanceResponseTopicPrefix(String distanceResponseTopicPrefix)
    {
        this.distanceResponseTopicPrefix = distanceResponseTopicPrefix;
    }


    public String getActionsRequestTopicName()
    {
        return actionsRequestTopicName;
    }


    public void setActionsRequestTopicName(String actionsRequestTopicName)
    {
        this.actionsRequestTopicName = actionsRequestTopicName;
    }


    public String getActionsResponseTopicPrefix()
    {
        return actionsResponseTopicPrefix;
    }


    public void setActionsResponseTopicPrefix(String actionsResponseTopicPrefix)
    {
        this.actionsResponseTopicPrefix = actionsResponseTopicPrefix;
    }


    public String getKbStateTopicPrefix()
    {
        return kbStateTopicPrefix;
    }


    public void setKbStateTopicPrefix(String kbStateTopicPrefix)
    {
        this.kbStateTopicPrefix = kbStateTopicPrefix;
    }


    public String getDevBehDetectionsTopicPrefix()
    {
        return devBehDetectionsTopicPrefix;
    }


    public void setDevBehDetectionsTopicPrefix(String devBehDetectionsTopicPrefix)
    {
        this.devBehDetectionsTopicPrefix = devBehDetectionsTopicPrefix;
    }


    public String getDevBehDetectionsDirPath()
    {
        return devBehDetectionsDirPath;
    }


    public void setDevBehDetectionsDirPath(String devBehDetectionsDirPath)
    {
        this.devBehDetectionsDirPath = devBehDetectionsDirPath;
    }


    public long getDevBehDetectionsStartFrameId()
    {
        return devBehDetectionsStartFrameId;
    }


    public void setDevBehDetectionsStartFrameId(long devBehDetectionsStartFrameId)
    {
        this.devBehDetectionsStartFrameId = devBehDetectionsStartFrameId;
    }


    public String getPerceptionResultDirPath()
    {
        return perceptionResultDirPath;
    }


    public void setPerceptionResultDirPath(String perceptionResultDirPath)
    {
        this.perceptionResultDirPath = perceptionResultDirPath;
    }


    public long getPerceptionInitialConsumedFrameId()
    {
        return perceptionInitialConsumedFrameId;
    }


    public void setPerceptionInitialConsumedFrameId(long perceptionInitialConsumedFrameId)
    {
        this.perceptionInitialConsumedFrameId = perceptionInitialConsumedFrameId;
    }


    public boolean isPerceptionVisualizationEnabled()
    {
        return perceptionVisualizationEnabled;
    }


    public void setPerceptionVisualizationEnabled(boolean perceptionVisualizationEnabled)
    {
        this.perceptionVisualizationEnabled = perceptionVisualizationEnabled;
    }


    public int getKbHistoryIntervalSec()
    {
        return kbHistoryIntervalSec;
    }


    public void setKbHistoryIntervalSec(int kbHistoryIntervalSec)
    {
        this.kbHistoryIntervalSec = kbHistoryIntervalSec;
    }


    public int getMaxOccludedDurationSec()
    {
        return maxOccludedDurationSec;
    }


    public void setMaxOccludedDurationSec(int maxOccludedDurationSec)
    {
        this.maxOccludedDurationSec = maxOccludedDurationSec;
    }


    public float getBoxContactPointLiftPercent()
    {
        return boxContactPointLiftPercent;
    }


    public void setBoxContactPointLiftPercent(float boxContactPointLiftPercent)
    {
        this.boxContactPointLiftPercent = boxContactPointLiftPercent;
    }


    public int getInferencePeriodSec()
    {
        return inferencePeriodSec;
    }


    public void setInferencePeriodSec(int inferencePeriodSec)
    {
        this.inferencePeriodSec = inferencePeriodSec;
    }


    public int getDevBehIgnorePeriodSec()
    {
        return devBehIgnorePeriodSec;
    }


    public void setDevBehIgnorePeriodSec(int devBehIgnorePeriodSec)
    {
        this.devBehIgnorePeriodSec = devBehIgnorePeriodSec;
    }


    public String getKbWorkerJarPath()
    {
        return kbWorkerJarPath;
    }


    public void setKbWorkerJarPath(String kbWorkerJarPath)
    {
        this.kbWorkerJarPath = kbWorkerJarPath;
    }


    public String getKbWorkerMemory()
    {
        return kbWorkerMemory;
    }


    public void setKbWorkerMemory(String kbWorkerMemory)
    {
        this.kbWorkerMemory = kbWorkerMemory;
    }


    public String getLibjplJavaLibraryPath()
    {
        return libjplJavaLibraryPath;
    }


    public void setLibjplJavaLibraryPath(String libjplJavaLibraryPath)
    {
        this.libjplJavaLibraryPath = libjplJavaLibraryPath;
    }


    public String getGeneralKbRulesFilePath()
    {
        return generalKbRulesFilePath;
    }


    public void setGeneralKbRulesFilePath(String generalKbRulesFilePath)
    {
        this.generalKbRulesFilePath = generalKbRulesFilePath;
    }


    public int getMaxActionDurationSec()
    {
        return maxActionDurationSec;
    }


    public void setMaxActionDurationSec(int maxActionDurationSec)
    {
        this.maxActionDurationSec = maxActionDurationSec;
    }


    public int getMaxChildSkeletonLengthMm()
    {
        return maxChildSkeletonLengthMm;
    }


    public void setMaxChildSkeletonLengthMm(int maxChildSkeletonLengthMm)
    {
        this.maxChildSkeletonLengthMm = maxChildSkeletonLengthMm;
    }


    public int getMaxQueuedFrames()
    {
        return maxQueuedFrames;
    }


    public void setMaxQueuedFrames(int maxQueuedFrames)
    {
        this.maxQueuedFrames = maxQueuedFrames;
    }


    public int getMaxProcessingFrames()
    {
        return maxProcessingFrames;
    }


    public void setMaxProcessingFrames(int maxProcessingFrames)
    {
        this.maxProcessingFrames = maxProcessingFrames;
    }


    public List<FileVideoProviderProperties> getFileVideoProviders()
    {
        return fileVideoProviders;
    }


    public void setFileVideoProviders(List<FileVideoProviderProperties> fileVideoProviders)
    {
        this.fileVideoProviders = fileVideoProviders;
    }


    public static class FileVideoProviderProperties
    {
        /**
         * Имя потока видеозаписи.
         */
        private String name;

        /**
         * Путь к файлу видеозаписи.
         */
        private String filePath;

        /**
         * Максимальное количество кадров в секунду для данного видео.
         * Если fps видео ниже, будет взято fps видео. Если выше, будет происходить прореживание.
         */
        private int maxFps;

        /**
         * Фокусное расстояние камеры в миллиметрах.
         */
        private float focalLengthMm;

        /**
         * Ширина/высота пикселя в миллиметрах. Предполагается, что ширина и высота равны.
         */
        private float pixelSizeMm;

        /**
         * Высота размещения камеры над плоскостью земли в миллиметрах.
         */
        private float cameraHeightMm;

        /**
         * Путь к файлу (в формате .pl), содержащему специфичные для конкретного видеопотока знания (например, с описанием
         * положения статических объектов) или null.
         */
        private String cameraKbRulesFilePath = null;


        public String getName()
        {
            return name;
        }


        public void setName(String name)
        {
            this.name = name;
        }


        public String getFilePath()
        {
            return filePath;
        }


        public void setFilePath(String filePath)
        {
            this.filePath = filePath;
        }


        public int getMaxFps()
        {
            return maxFps;
        }


        public void setMaxFps(int maxFps)
        {
            this.maxFps = maxFps;
        }


        public float getFocalLengthMm()
        {
            return focalLengthMm;
        }


        public void setFocalLengthMm(float focalLengthMm)
        {
            this.focalLengthMm = focalLengthMm;
        }


        public float getPixelSizeMm()
        {
            return pixelSizeMm;
        }


        public void setPixelSizeMm(float pixelSizeMm)
        {
            this.pixelSizeMm = pixelSizeMm;
        }


        public float getCameraHeightMm()
        {
            return cameraHeightMm;
        }


        public void setCameraHeightMm(float cameraHeightMm)
        {
            this.cameraHeightMm = cameraHeightMm;
        }


        public String getCameraKbRulesFilePath()
        {
            return cameraKbRulesFilePath;
        }


        public void setCameraKbRulesFilePath(String cameraKbRulesFilePath)
        {
            this.cameraKbRulesFilePath = cameraKbRulesFilePath;
        }
    }
}
